@@ -19,13 +19,37 @@ except ImportError as e:
     pass
 
 
+def crpath(__file__, name):
+    """ for use in combination with configure e.g.
+        `auth = oa.configure(oa.cpath(__file__))`
+        assuming that `auth-config.py` is the name
+        of your auth config file """
+    # NOTE: never set a default value for name
+    # because the call to this function should
+    # document the name of the file in a way that
+    # is easy to see locally
+    return pathlib.Path(__file__).parent / name
+
+
 def configure(auth_config_path, include=tuple()):
     """ hrm """
     return AuthConfig(auth_config_path, include=include)
 
 
+def configure_here(name, calling__name__, include=tuple()):
+    calling_module = importlib.import_module(calling__name__)
+    calling__file__ = calling_module.__file__
+    return AuthConfig._from_relative_path(calling__file__,
+                                          name,
+                                          include=include,
+                                          calling_module=calling_module)
+
+
 def configure_relative(name, include=tuple()):
-    """ hrm """
+    """ WARNING very bad performance due to using inspect """
+    warnings.warn(f'configure_relative is deprecated please switch to configure_here',
+                    DeprecationWarning,
+                    stacklevel=2)
     stack = inspect.stack(0)
     s1 = stack[1]
     calling__file__ = s1.filename
@@ -212,8 +236,25 @@ class ConfigBase:
                       stacklevel=2)
         return self.load()
 
+    def _mtime_changed(self):
+        """ Check if the modified time of self._path has changed.
+            Still hits the disk but can be used to avoid force a
+            full read of the file when there are no changes. """
+
+        if self._path is not None:  # no path, no disk, no worries
+            mtime = self._path.stat().st_mtime
+            if not hasattr(self, '_last_mtime'):
+                last_mtime = self._last_mtime = mtime
+            else:
+                last_mtime, self._last_mtime = self._last_mtime, mtime
+
+            return mtime != last_mtime
+
     def load(self):
-        return self._load_type()
+        if not hasattr(self, '_blob') or self._mtime_changed():
+            self._blob = self._load_type()
+
+        return self._blob
 
     def dump(self, config):
         """ Don't use this ... seriously """
@@ -527,6 +568,11 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         with open(ucp, 'wt') as f:
             f.write(self._serialize_user_config(format))
 
+    def get_list(self, variable_name):
+        """ if you know a variable holds a list use this """
+        var = self.get(variable_name, for_list=True)
+        return var
+
     def get_path(self, variable_name):
         """ if you know a variable holds a path use this to autoconvert """
         var = self.get(variable_name, for_path=True)
@@ -601,6 +647,7 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
 
     def get(self, variable_name, *args, **kwargs):
         """ look up the value of a variable name from auth store or config """
+        for_list = 'for_list' in kwargs and kwargs['for_list']
         for_path = 'for_path' in kwargs and kwargs['for_path']
         av = self.get_blob('auth-variables')
         if variable_name not in av:
@@ -638,12 +685,15 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         defaults = []
         if not isinstance(user_variable_value, dict):
             if isinstance(user_variable_value, list):
-                if not for_path:
+                if for_list:
+                    user_variable_value = [user_variable_value]
+                elif not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
                 else:
-                    user_variable_value = [self.user_config._pathit(p)
-                                   for p in user_variable_value if p is not None]
+                    user_variable_value = [
+                        self.user_config._pathit(p)
+                        for p in user_variable_value if p is not None]
 
                 defaults.extend(user_variable_value)
             else:
@@ -659,7 +709,9 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         elif 'default' in user_variable_value:
             d = user_variable_value['default']
             if isinstance(d, list):
-                if not for_path:
+                if for_list:
+                    d = [d]
+                elif not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
                 else:
@@ -675,7 +727,9 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
 
         if not isinstance(auth_variable_value, dict):
             if isinstance(auth_variable_value, list):
-                if not for_path:
+                if for_list:
+                    auth_variable_value = [auth_variable_value]
+                elif not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
                 else:
@@ -694,7 +748,9 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
         elif 'default' in auth_variable_value:
             d = auth_variable_value['default']
             if isinstance(d, list):
-                if not for_path:
+                if for_list:
+                    d = [d]
+                elif not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
                 else:
@@ -725,6 +781,11 @@ class AuthConfig(DecoBase, ConfigBase):  # FIXME this is more a schema?
             get_uc = self.user_config._get_path
             def get_default(d):
                 return d
+        elif for_list:
+            get_uc = self.user_config._get
+            def get_default(d):
+                return d[0]
+
         else:
             get_uc = self.user_config._get
             def get_default(d):
@@ -815,11 +876,20 @@ class UserConfig(ConfigBase):
         return stores.Authinfo(self._blob_path(blob))
 
     def _get_store(self, store, blob):
+        cache_name = f'_c_{store.__name__}'
+        if hasattr(self, cache_name):
+            return getattr(self, cache_name)
+
         path = self._blob_path(blob)
         try:
-            return store(path)
+            store_obj = store(path)
+            setattr(self, cache_name, store_obj)
+            return store_obj
         except FileNotFoundError as e:
-            err = exc.SomethingWrongWithVariableInConfig(f'{path} in {self._path}')
+            msg = (f'In the config located at: {self._path!r}\n'
+                   f'the following path does not exist: {path!r}\n'
+                   f'the raw value from the config was: {blob["path"]}')
+            err = exc.SomethingWrongWithVariableInConfig(msg)
             raise err from e
 
     def _secrets(self, blob):
@@ -843,6 +913,7 @@ class UserConfig(ConfigBase):
     def get(self, variable_name, *args, **kwargs):
         """ look up the value of a variable name from auth store or config """
         # ah the problem of interleveing values from sources of different rank ...
+        for_list = 'for_list' in kwargs and kwargs['for_list']
         for_path = 'for_path' in kwargs and kwargs['for_path']
         auth_variable_value = self.get_blob('auth-variables', variable_name)
         if auth_variable_value is None:
@@ -851,7 +922,9 @@ class UserConfig(ConfigBase):
         defaults = []
         if not isinstance(auth_variable_value, dict):
             if isinstance(auth_variable_value, list):
-                if not for_path:
+                if for_list:
+                    auth_variable_value = [auth_variable_value]
+                elif not for_path:
                     log.warning(f'attempting to get a default value for {variable_name} '
                                 'that is a list did you want get_path?')
 
@@ -945,6 +1018,9 @@ class UserConfig(ConfigBase):
 
     @property
     def alt_config(self):
+        if hasattr(self, '_c_alt_config'):
+            return self._c_alt_config
+
         try:
             path = self._alt_config_path
             _test = self.load()
@@ -952,9 +1028,12 @@ class UserConfig(ConfigBase):
             rename = _test.pop('rename', None)
             if _test:
                 raise ValueError('configs with top level alt-config may '
-                                 f'have only a rename section\n{_test}')
+                                f'have only a rename section\n{_test}')
 
-            return self._from_user_alt_config(path, self.auth_config, rename)
+            self._c_alt_config = self._from_user_alt_config(path,
+                                                            self.auth_config,
+                                                            rename)
+            return self._c_alt_config
         except KeyError:
             pass
 
@@ -967,7 +1046,7 @@ class UserConfig(ConfigBase):
             if hasattr(self, '_secrets_runtime') and self.get_blob('auth-stores', 'runtime'):
                 return self._secrets_runtime
             else:
-                raise e
+                raise
 
     @property
     def _path_sources(self):
